class Amp < Formula
  desc "Text editor for your terminal"
  homepage "https://amp.rs"
  license "GPL-3.0-or-later"
  head "https://github.com/jmacdonald/amp.git", branch: "main"

  stable do
    url "https://github.com/jmacdonald/amp/archive/refs/tags/0.7.0.tar.gz"
    sha256 "d77946c042df6c27941f6994877e0e62c71807f245b16b41cf00dbf8b3553731"

    patch do
      url "https://github.com/jmacdonald/amp/commit/4ce866de7a2e1613951002ff61563a80e19a5c0c.patch?full_index=1"
      sha256 "0837555e28ca95b366932af02cdbad41a26d1c7f57545f04616258fadc6e96ec"
    end
  end

  depends_on "cmake" => :build
  depends_on "rust" => :build

  uses_from_macos "python" => :build
  uses_from_macos "zlib"

  on_linux do
    depends_on "libxcb"
  end

  def install
    system "cargo", "install", *std_cargo_args
  end

  test do
    require "pty"
    require "io/console"

    PTY.spawn(bin/"amp", "test.txt") do |r, w, _pid|
      r.winsize = [80, 43]
      sleep 1
      # switch to insert mode and add data
      w.write "i"
      sleep 1
      w.write "test data"
      sleep 1
      # escape to normal mode, save the file, and quit
      w.write "\e"
      sleep 1
      w.write "s"
      sleep 1
      w.write "Q"
      begin
        r.read
      rescue Errno::EIO
        # GNU/Linux raises EIO when read is done on closed pty
      end
    end

    assert_match "test data\n", (testpath/"test.txt").read
  end
end
